jstack-report.ansi


*use-ansi*clj

Rebind to false to suppress ANSI codes (e.g. when piping to a file).

Rebind to false to suppress ANSI codes (e.g. when piping to a file).
sourceraw docstring

ansiclj

(ansi code)

Output an ANSI escape code using a style key. (ansi :blue) (ansi :underline) Note, try (style-test-page) to see all available styles. If use-ansi is bound to false, outputs an empty string instead of an ANSI code. You can use this to temporarily or permanently turn off ANSI color in some part of your program, while maintaining only 1 version of your marked-up text.

Output an ANSI escape code using a style key.
 (ansi :blue)
 (ansi :underline)
Note, try (style-test-page) to see all available styles.
If *use-ansi* is bound to false, outputs an empty string instead of an
ANSI code. You can use this to temporarily or permanently turn off
ANSI color in some part of your program, while maintaining only 1
version of your marked-up text.
sourceraw docstring

ANSI-CODESclj

source

ESCclj

source

styleclj

(style s & codes)

Applies ANSI color and style to a text string. (style "foo" :red) (style "foo" :red :underline) (style "foo" :red :bg-blue :underline)

Applies ANSI color and style to a text string.
(style "foo" :red)
(style "foo" :red :underline)
(style "foo" :red :bg-blue :underline)
sourceraw docstring

style-test-pageclj

(style-test-page)

Print the list of supported ANSI styles, each style name shown with its own style.

Print the list of supported ANSI styles, each style name shown
with its own style.
sourceraw docstring

with-ansicljmacro

(with-ansi & code)

Runs the given code with the use-ansi variable temporarily bound to true, to enable the production of any ANSI color codes specified in the code.

Runs the given code with the use-ansi variable temporarily bound to
true, to enable the production of any ANSI color codes specified in
the code.
sourceraw docstring

without-ansicljmacro

(without-ansi & code)

Runs the given code with the use-ansi variable temporarily bound to false, to suppress the production of any ANSI color codes specified in the code.

Runs the given code with the use-ansi variable temporarily bound to
false, to suppress the production of any ANSI color codes specified
in the code.
sourceraw docstring

wrap-styleclj

(wrap-style base wrapper & styles)

Wraps a base string with a stylized wrapper. If the wrapper is a string it will be placed on both sides of the base, and if it is a seq the first and second items will wrap the base. To wrap debug with red brackets => [debug]: (wrap-style "debug" ["[" "]"] :red)

Wraps a base string with a stylized wrapper.
If the wrapper is a string it will be placed on both sides of the base,
and if it is a seq the first and second items will wrap the base.
To wrap debug with red brackets => [debug]:
(wrap-style "debug" ["[" "]"] :red)
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries