jstack-report.main


-mainclj

(-main & args)
source

cli-optionsclj

source

error-msgclj

(error-msg errors)
source

exitclj

(exit status msg)
source

main-entrypointclj

(main-entrypoint hard-exit-on-errors? [& args])
source

repl-mainclj

(repl-main & args)
source

usageclj

(usage options-summary)
(usage options-summary extra)
source

validate-argsclj

(validate-args args)

Validate command line arguments. Either return a map indicating the program should exit (with a error message, and optional ok status), or a map indicating the action the program should take and the options provided.

Validate command line arguments. Either return a map indicating the program
should exit (with a error message, and optional ok status), or a map
indicating the action the program should take and the options provided.
sourceraw docstring

version-stringclj

(version-string)

Render the human-readable footer shown by --help. Falls back to a '(dev)' placeholder when no version.edn is available (running from sources without having built the uberjar yet).

Render the human-readable footer shown by --help. Falls back to a
'(dev)' placeholder when no version.edn is available (running from
sources without having built the uberjar yet).
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries