(validate-args args)Validate command line arguments. Either return a map indicating the program should exit (with a error message, and optional ok status), or a map indicating the action the program should take and the options provided.
Validate command line arguments. Either return a map indicating the program should exit (with a error message, and optional ok status), or a map indicating the action the program should take and the options provided.
(version-string)Render the human-readable footer shown by --help. Falls back to a '(dev)' placeholder when no version.edn is available (running from sources without having built the uberjar yet).
Render the human-readable footer shown by --help. Falls back to a '(dev)' placeholder when no version.edn is available (running from sources without having built the uberjar yet).
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |